@@ -4,11 +4,11 @@ build_time_vars = {'ABIFLAGS': '',
  'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
  'ALIGNOF_LONG': 8,
- 'ALIGNOF_MAX_ALIGN_T': 8,
+ 'ALIGNOF_MAX_ALIGN_T': 16,
  'ALIGNOF_SIZE_T': 8,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
- 'AR': '/usr/bin/ar',
+ 'AR': 'ar',
  'ARFLAGS': 'rcs',
  'BASECFLAGS': '-fno-strict-overflow -Wsign-compare -Wunreachable-code',
  'BASECPPFLAGS': '',
@@ -20,7 +20,7 @@ build_time_vars = {'ABIFLAGS': '',
  'BOOTSTRAP_HEADERS': '\\',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'powerpc64-unknown-openbsd7.7',
+ 'BUILD_GNU_TYPE': 'mips64-unknown-openbsd7.8',
  'BUILD_SCRIPTS_DIR': 'build/scripts-3.12',
  'BYTESTR_DEPS': '\\',
  'CC': 'cc -pthread',
@@ -35,19 +35,18 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-O2 -pipe',
- 'CONFIGURE_CFLAGS_NODIST': '-flto=thin -g -std=c11 -Wextra '
-                            '-Wno-unused-parameter '
+ 'CONFIGURE_CFLAGS_NODIST': '-std=c11 -Wextra -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '-I/usr/local/include',
  'CONFIGURE_LDFLAGS': '-L/usr/local/lib/',
- 'CONFIGURE_LDFLAGS_NODIST': '-flto=thin -g',
- 'CONFIGURE_LDFLAGS_NOLTO': '-flto=thin',
+ 'CONFIGURE_LDFLAGS_NODIST': '',
+ 'CONFIGURE_LDFLAGS_NOLTO': '',
  'CONFIG_ARGS': "'--with-ensurepip=no' '--enable-shared' '--enable-ipv6' "
                 "'--with-system-expat' '--with-system-ffi' "
-                "'--enable-loadable-sqlite-extensions' '--with-lto' "
+                "'--enable-loadable-sqlite-extensions' '--with-lto=no' "
                 "'--prefix=/usr/local' '--sysconfdir=/etc' "
                 "'--mandir=/usr/local/man' '--infodir=/usr/local/info' "
                 "'--localstatedir=/var' '--disable-silent-rules' "
@@ -60,9 +59,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/local/include',
  'CONFINCLUDEPY': '/usr/local/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/usr/obj/ports/Python-3.12.10/Python-3.12.10/coverage.info',
+ 'COVERAGE_INFO': '/pobj/Python-3.12.11/Python-3.12.11/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/usr/obj/ports/Python-3.12.10/Python-3.12.10/lcov-report',
+ 'COVERAGE_REPORT': '/pobj/Python-3.12.11/Python-3.12.11/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
@@ -608,17 +607,17 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ZLIB_H': 0,
  'HAVE__GETPTY': 0,
  'HOSTRUNNER': '',
- 'HOST_GNU_TYPE': 'powerpc64-unknown-openbsd7.7',
+ 'HOST_GNU_TYPE': 'mips64-unknown-openbsd7.8',
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include '
                    '/usr/local/include/python3.12 '
                    '/usr/local/include/python3.12',
  'INCLUDEDIR': '/usr/local/include',
  'INCLUDEPY': '/usr/local/include/python3.12',
- 'INSTALL': '/usr/obj/ports/Python-3.12.10/bin/install -c',
- 'INSTALL_DATA': '/usr/obj/ports/Python-3.12.10/bin/install -c -m 644',
- 'INSTALL_PROGRAM': '/usr/obj/ports/Python-3.12.10/bin/install -c -s -m 755',
- 'INSTALL_SCRIPT': '/usr/obj/ports/Python-3.12.10/bin/install -c -m 755',
- 'INSTALL_SHARED': '/usr/obj/ports/Python-3.12.10/bin/install -c -m 755',
+ 'INSTALL': '/pobj/Python-3.12.11/bin/install -c',
+ 'INSTALL_DATA': '/pobj/Python-3.12.11/bin/install -c -m 644',
+ 'INSTALL_PROGRAM': '/pobj/Python-3.12.11/bin/install -c -s -m 755',
+ 'INSTALL_SCRIPT': '/pobj/Python-3.12.11/bin/install -c -m 755',
+ 'INSTALL_SHARED': '/pobj/Python-3.12.11/bin/install -c -m 755',
  'INSTSONAME': 'libpython3.12.so.0.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
@@ -633,8 +632,8 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBDIR': '/usr/local/lib',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
  'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare -Wunreachable-code '
-                    '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe -flto=thin '
-                    '-g -std=c11 -Wextra -Wno-unused-parameter '
+                    '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe -std=c11 '
+                    '-Wextra -Wno-unused-parameter '
                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                     '-Werror=implicit-function-declaration -fvisibility=hidden '
                     '-I/usr/local/include -I./Include/internal -I. -I./Include '
@@ -643,8 +642,8 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBEXPAT_OBJS': '\\',
  'LIBHACL_CFLAGS': '-I./Modules/_hacl/include -D_BSD_SOURCE -D_DEFAULT_SOURCE '
                    '-fno-strict-overflow -Wsign-compare -Wunreachable-code '
-                   '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe -flto=thin '
-                   '-g -std=c11 -Wextra -Wno-unused-parameter '
+                   '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe -std=c11 '
+                   '-Wextra -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration -fvisibility=hidden '
                    '-I/usr/local/include -I./Include/internal -I. -I./Include '
@@ -658,12 +657,11 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 -DANSI=1 '
                     '-DHAVE_UINT128_T=1 -fno-strict-overflow -Wsign-compare '
                     '-Wunreachable-code -DNDEBUG -O2 -pipe   -fPIC -O2 -pipe '
-                    '-O2 -pipe -flto=thin -g -std=c11 -Wextra '
-                    '-Wno-unused-parameter -Wno-missing-field-initializers '
-                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                    '-fvisibility=hidden -I/usr/local/include '
-                    '-I./Include/internal -I. -I./Include -I/usr/local/include '
-                    '-fPIC -fPIC',
+                    '-O2 -pipe -std=c11 -Wextra -Wno-unused-parameter '
+                    '-Wno-missing-field-initializers -Wstrict-prototypes '
+                    '-Werror=implicit-function-declaration -fvisibility=hidden '
+                    '-I/usr/local/include -I./Include/internal -I. -I./Include '
+                    '-I/usr/local/include -fPIC -fPIC',
  'LIBMPDEC_HEADERS': '\\',
  'LIBMPDEC_OBJS': '\\',
  'LIBOBJDIR': 'Python/',
@@ -1031,8 +1029,8 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha2,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
                              '-Wunreachable-code -DNDEBUG -O2 -pipe   -fPIC '
-                             '-O2 -pipe -O2 -pipe -flto=thin -g -std=c11 '
-                             '-Wextra -Wno-unused-parameter '
+                             '-O2 -pipe -O2 -pipe -std=c11 -Wextra '
+                             '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
@@ -1042,31 +1040,27 @@ build_time_vars = {'ABIFLAGS': '',
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare -Wunreachable-code -DNDEBUG '
               '-O2 -pipe   -fPIC -O2 -pipe -O2 -pipe',
- 'PY_CFLAGS_NODIST': '-flto=thin -g -std=c11 -Wextra -Wno-unused-parameter '
+ 'PY_CFLAGS_NODIST': '-std=c11 -Wextra -Wno-unused-parameter '
                      '-Wno-missing-field-initializers -Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden -I/usr/local/include '
                      '-I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -Wunreachable-code '
-                   '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe -flto=thin '
-                   '-g -std=c11 -Wextra -Wno-unused-parameter '
+                   '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe -std=c11 '
+                   '-Wextra -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration -fvisibility=hidden '
                    '-I/usr/local/include -I./Include/internal -I. -I./Include '
                    '-I/usr/local/include -fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-L/usr/local/lib/ -flto=thin -g '
-                    '-L/usr/obj/ports/Python-3.12.10/Python-3.12.10 '
+ 'PY_CORE_LDFLAGS': '-L/usr/local/lib/ -L/pobj/Python-3.12.11/Python-3.12.11 '
                     '-L/usr/local/lib/',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/local/include',
  'PY_ENABLE_SHARED': 1,
  'PY_HAVE_PERF_TRAMPOLINE': 0,
  'PY_LDFLAGS': '-L/usr/local/lib/',
- 'PY_LDFLAGS_NODIST': '-flto=thin -g '
-                      '-L/usr/obj/ports/Python-3.12.10/Python-3.12.10 '
-                      '-L/usr/local/lib/',
- 'PY_LDFLAGS_NOLTO': '-L/usr/local/lib/ -flto=thin '
-                     '-L/usr/obj/ports/Python-3.12.10/Python-3.12.10 '
+ 'PY_LDFLAGS_NODIST': '-L/pobj/Python-3.12.11/Python-3.12.11 -L/usr/local/lib/',
+ 'PY_LDFLAGS_NOLTO': '-L/usr/local/lib/  -L/pobj/Python-3.12.11/Python-3.12.11 '
                      '-L/usr/local/lib/',
  'PY_SQLITE_ENABLE_LOAD_EXTENSION': 1,
  'PY_SQLITE_HAVE_SERIALIZE': 1,
@@ -1074,7 +1068,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
                         '-Wunreachable-code -DNDEBUG -O2 -pipe   -fPIC -O2 '
-                        '-pipe -O2 -pipe -flto=thin -g -std=c11 -Wextra '
+                        '-pipe -O2 -pipe -std=c11 -Wextra '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
@@ -1092,7 +1086,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.12.10/Python-3.12.10',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/pobj/Python-3.12.11/Python-3.12.11',
  'SCRIPTDIR': '/usr/local/lib',
  'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
  'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
@@ -1166,7 +1160,7 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_FPOS_T': 8,
  'SIZEOF_INT': 4,
  'SIZEOF_LONG': 8,
- 'SIZEOF_LONG_DOUBLE': 8,
+ 'SIZEOF_LONG_DOUBLE': 16,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
@@ -1197,11 +1191,11 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.12.10/Python-3.12.10 '
-               './python -E',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/pobj/Python-3.12.11/Python-3.12.11 ./python '
+               '-E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.12.10/Python-3.12.10 '
-               './python -E ./Tools/scripts/run_tests.py',
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/pobj/Python-3.12.11/Python-3.12.11 ./python '
+               '-E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
  'TEST_MODULES': 'yes',
@@ -1230,8 +1224,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/obj/ports/Python-3.12.10/Python-3.12.10',
- 'abs_srcdir': '/usr/obj/ports/Python-3.12.10/Python-3.12.10',
+ 'abs_builddir': '/pobj/Python-3.12.11/Python-3.12.11',
+ 'abs_srcdir': '/pobj/Python-3.12.11/Python-3.12.11',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
  'prefix': '/usr/local',
